==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/EC2/DescribeVpcAttribute.pm <==

package Paws::EC2::DescribeVpcAttribute;
  use Moose;
  has Attribute => (is => 'ro', isa => 'Str', required => 1);
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
  has VpcId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeVpcAttribute');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DescribeVpcAttributeResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DescribeVpcAttribute - Arguments for method DescribeVpcAttribute on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeVpcAttribute on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method DescribeVpcAttribute.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeVpcAttribute.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
   # To describe the enableDnsSupport attribute
   # This example describes the enableDnsSupport attribute. This attribute
   # indicates whether DNS resolution is enabled for the VPC. If this attribute
   # is true, the Amazon DNS server resolves DNS hostnames for your instances to
   # their corresponding IP addresses; otherwise, it does not.
    my $DescribeVpcAttributeResult = $ec2->DescribeVpcAttribute(
      {
        'Attribute' => 'enableDnsSupport',
        'VpcId'     => 'vpc-a01106c2'
      }
    );

    # Results:
    my $EnableDnsSupport = $DescribeVpcAttributeResult->EnableDnsSupport;
    my $VpcId            = $DescribeVpcAttributeResult->VpcId;

    # Returns a L<Paws::EC2::DescribeVpcAttributeResult> object.
    # To describe the enableDnsHostnames attribute
    # This example describes the enableDnsHostnames attribute. This attribute
    # indicates whether the instances launched in the VPC get DNS hostnames. If
    # this attribute is true, instances in the VPC get DNS hostnames; otherwise,
    # they do not.
    my $DescribeVpcAttributeResult = $ec2->DescribeVpcAttribute(
      {
        'VpcId'     => 'vpc-a01106c2',
        'Attribute' => 'enableDnsHostnames'
      }
    );

    # Results:
    my $VpcId              = $DescribeVpcAttributeResult->VpcId;
    my $EnableDnsHostnames = $DescribeVpcAttributeResult->EnableDnsHostnames;

    # Returns a L<Paws::EC2::DescribeVpcAttributeResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/DescribeVpcAttribute>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Attribute => Str

The VPC attribute.

Valid values are: C<"enableDnsSupport">, C<"enableDnsHostnames">

=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> VpcId => Str

The ID of the VPC.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeVpcAttribute in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/EC2/DescribeVpcAttribute.pm <==

package Paws::EC2::DescribeVpcAttribute;
  use Moose;
  has Attribute => (is => 'ro', isa => 'Str', required => 1);
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
  has VpcId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeVpcAttribute');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DescribeVpcAttributeResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DescribeVpcAttribute - Arguments for method DescribeVpcAttribute on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeVpcAttribute on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method DescribeVpcAttribute.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeVpcAttribute.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
   # To describe the enableDnsSupport attribute
   # This example describes the enableDnsSupport attribute. This attribute
   # indicates whether DNS resolution is enabled for the VPC. If this attribute
   # is true, the Amazon DNS server resolves DNS hostnames for your instances to
   # their corresponding IP addresses; otherwise, it does not.
    my $DescribeVpcAttributeResult = $ec2->DescribeVpcAttribute(
      {
        'Attribute' => 'enableDnsSupport',
        'VpcId'     => 'vpc-a01106c2'
      }
    );

    # Results:
    my $EnableDnsSupport = $DescribeVpcAttributeResult->EnableDnsSupport;
    my $VpcId            = $DescribeVpcAttributeResult->VpcId;

    # Returns a L<Paws::EC2::DescribeVpcAttributeResult> object.
    # To describe the enableDnsHostnames attribute
    # This example describes the enableDnsHostnames attribute. This attribute
    # indicates whether the instances launched in the VPC get DNS hostnames. If
    # this attribute is true, instances in the VPC get DNS hostnames; otherwise,
    # they do not.
    my $DescribeVpcAttributeResult = $ec2->DescribeVpcAttribute(
      {
        'Attribute' => 'enableDnsHostnames',
        'VpcId'     => 'vpc-a01106c2'
      }
    );

    # Results:
    my $EnableDnsHostnames = $DescribeVpcAttributeResult->EnableDnsHostnames;
    my $VpcId              = $DescribeVpcAttributeResult->VpcId;

    # Returns a L<Paws::EC2::DescribeVpcAttributeResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/DescribeVpcAttribute>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Attribute => Str

The VPC attribute.

Valid values are: C<"enableDnsSupport">, C<"enableDnsHostnames">

=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> VpcId => Str

The ID of the VPC.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeVpcAttribute in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
